==> haskell-libffi-0.1-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-libffi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 libffi
version:              0.1
visibility:           public
id:                   libffi-0.1-I5Zq0Cmk0zGv0kMknkm1v
key:                  libffi-0.1-I5Zq0Cmk0zGv0kMknkm1v
license:              BSD-3-Clause
copyright:            Remi Turk 2008-2009
maintainer:           remi.turk@gmail.com
author:               Remi Turk
stability:            alpha
synopsis:             A binding to libffi
description:
    A binding to libffi, allowing C functions of types only known at runtime to be called from Haskell.

category:             Foreign
abi:                  274c9d70e0b206c8ad1bd1ef8fad10f7
exposed:              True
exposed-modules:
    Foreign.LibFFI Foreign.LibFFI.Base Foreign.LibFFI.FFITypes
    Foreign.LibFFI.Internal Foreign.LibFFI.Types

import-dirs:          /usr/lib/ghc-8.8.1/site-local/libffi-0.1
library-dirs:
    /usr/lib/ghc-8.8.1/site-local/libffi-0.1 /usr/lib/../lib

dynamic-library-dirs: /usr/lib /usr/lib/../lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/libffi-0.1
hs-libraries:         HSlibffi-0.1-I5Zq0Cmk0zGv0kMknkm1v
extra-libraries:      ffi ffi
include-dirs:         /usr/lib/libffi-3.2.1/include
includes:             ffi.h ffitarget.h
depends:              base-4.13.0.0 bytestring-0.10.9.0
haddock-interfaces:   /usr/share/doc/haskell-libffi/html/libffi.haddock
haddock-html:         /usr/share/doc/haskell-libffi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-libffi-0.1-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-libffi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 libffi
version:              0.1
visibility:           public
id:                   libffi-0.1-5FWdBJ1jvy6GIUKiwt0Ewx
key:                  libffi-0.1-5FWdBJ1jvy6GIUKiwt0Ewx
license:              BSD-3-Clause
copyright:            Remi Turk 2008-2009
maintainer:           remi.turk@gmail.com
author:               Remi Turk
stability:            alpha
synopsis:             A binding to libffi
description:
    A binding to libffi, allowing C functions of types only known at runtime to be called from Haskell.

category:             Foreign
abi:                  631a43e8788b6a7a7560e045b0e61e76
exposed:              True
exposed-modules:
    Foreign.LibFFI Foreign.LibFFI.Base Foreign.LibFFI.FFITypes
    Foreign.LibFFI.Internal Foreign.LibFFI.Types

import-dirs:          /usr/lib/ghc-8.8.2/site-local/libffi-0.1
library-dirs:
    /usr/lib/ghc-8.8.2/site-local/libffi-0.1 /usr/lib/../lib

dynamic-library-dirs: /usr/lib /usr/lib/../lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.2/libffi-0.1
hs-libraries:         HSlibffi-0.1-5FWdBJ1jvy6GIUKiwt0Ewx
extra-libraries:      ffi ffi
include-dirs:         /usr/lib/libffi-3.2.1/include
includes:             ffi.h ffitarget.h
depends:              base-4.13.0.0 bytestring-0.10.10.0
haddock-interfaces:   /usr/share/doc/haskell-libffi/html/libffi.haddock
haddock-html:         /usr/share/doc/haskell-libffi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
